==> marquee_in_flutter-1.0.1.tar.gz: lib/alternatemarquee.dart <==
import 'package:flutter/cupertino.dart';
import 'speed.dart';

class AlternateMarquee extends StatefulWidget {

  final List<Widget> items;
  final Speed speed;

  AlternateMarquee({
    Key key,
    @required this.items,
    this.speed = Speed.normal
  }): super(key: key);

  @override
  _AlternateMarqueeState createState() => _AlternateMarqueeState();
}

class _AlternateMarqueeState extends State<AlternateMarquee> {

  ScrollController _scrollController;

  @override
  void initState() {
    _scrollController = ScrollController();
    WidgetsBinding.instance.addPostFrameCallback((_) async {
      Future.doWhile(_scroll);
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      scrollDirection: Axis.horizontal,
      child: Row(children: widget.items),
      controller: _scrollController,
      physics: NeverScrollableScrollPhysics(),// not allow the user to scroll.
    );
  }

  @override
  void dispose(){
    _scrollController.dispose();
    super.dispose();
  }

  Future<bool> _scroll() async {
    if (widget.speed == Speed.stop) {
      return false;
    }

    await Future.delayed(widget.speed.pauseDuration);
    _scrollController.animateTo(_scrollController.position.maxScrollExtent, duration: widget.speed.animationDuration, curve: Curves.easeOut);
    await Future.delayed(widget.speed.pauseDuration);
    _scrollController.animateTo(_scrollController.position.minScrollExtent, duration: widget.speed.backDuration, curve: Curves.easeOut);
    return true;
  }
}

==> marquee_in_flutter-1.0.2.tar.gz: lib/alternatemarquee.dart <==
import 'package:flutter/cupertino.dart';
import 'speed.dart';

class AlternateMarquee extends StatefulWidget {

  final List<Widget> items;
  final Speed speed;

  AlternateMarquee({
    Key key,
    @required this.items,
    this.speed = Speed.normal
  }): super(key: key);

  @override
  _AlternateMarqueeState createState() => _AlternateMarqueeState();
}

class _AlternateMarqueeState extends State<AlternateMarquee> {

  ScrollController _scrollController;

  @override
  void initState() {
    _scrollController = ScrollController();
    WidgetsBinding.instance.addPostFrameCallback((_) async {
      Future.doWhile(_scroll);
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Center(
      child: SingleChildScrollView(
        scrollDirection: Axis.horizontal,
        child: Row(children: widget.items),
        controller: _scrollController,
        physics: NeverScrollableScrollPhysics(), // not allow the user to scroll.
      )
    );
  }

  @override
  void dispose(){
    _scrollController.dispose();
    super.dispose();
  }

  Future<bool> _scroll() async {
    await Future.delayed(widget.speed.pauseDuration);
    _scrollController.animateTo(widget.speed == Speed.stop ? 0.0 : _scrollController.position.maxScrollExtent, duration: widget.speed.animationDuration, curve: Curves.easeOut);
    await Future.delayed(widget.speed.pauseDuration);
    _scrollController.animateTo(widget.speed == Speed.stop ? 0.0 : _scrollController.position.minScrollExtent, duration: widget.speed.backDuration, curve: Curves.easeOut);
    return true;
  }
}
